Module context
error_
forge
1.0.0
Module context
Module Items
Structs
Traits
In crate error_
forge
error_forge
Module
context
Structs

Context
Error
A wrapper error type that attaches contextual information to an error.
Traits

Result
Ext
Extension trait for Result types to add context to errors