Module macros

Module macros 

Structs

ErrorContext
Error context passed to registered hooks

Enums

ErrorLevel
Error hook types for centralized error handling

Functions

register_error_hook
Register a callback function to be called when errors are created
try_register_error_hook
Attempt to register a callback function to be called when errors are created.