Structs
- Error
Context - Error context passed to registered hooks
Enums
- Error
Level - Error hook types for centralized error handling
Functions
- register_
error_ hook - Register a callback function to be called when errors are created
- try_
register_ error_ hook - Attempt to register a callback function to be called when errors are created.