Module macros

Module macros 

Structs

ErrorContext
Error context passed to registered hooks.

Enums

ErrorLevel
Error severity level passed to a registered hook callback.

Functions

register_error_hookDeprecated
Register a callback to be called when errors are created.
try_register_error_hook
Attempt to register a callback to be called when errors are created.